==> global-0.0.31.tar.gz: lib/src/routes/GWebViewRoute.dart <==
import 'package:flutter/material.dart';
import 'package:global/global.dart';

abstract class GWebViewRoute extends StatefulWidget {
  final Map<String, dynamic> arguments;

  const GWebViewRoute(this.arguments, {super.key});
}

abstract class GWebViewRouteState<T extends GWebViewRoute>
    extends State<GWebViewRoute> {
  late String pageTitle;
  late InAppWebViewController webviewController;
  bool progDialogShowing = false;
  late InAppWebView webView;
  Uri? initialUri;

  @override
  void initState() {
    super.initState();
    initialUri = Uri.tryParse(widget.arguments[GKeys.initialWebviewData]);
    pageTitle = GTexts.untitled;
    webView = InAppWebView(
      initialData: initialUri == null
          ? InAppWebViewInitialData(
              data: widget.arguments[GKeys.initialWebviewData])
          : null,
      initialUrlRequest: initialUri == null
          ? null
          : () {
              /*1. Delay put as progress dialog was getting pushed during build
                2. Progress dialog push handling being done here, so that user doesn't feel
                   that screen is unresponsive for long, after entering webview*/
              Future.delayed(
                  const Duration(milliseconds: 200), showProgDialogHandler);
              return URLRequest(url: WebUri.uri(initialUri!));
            }(),
      initialOptions: InAppWebViewGroupOptions(
        crossPlatform: InAppWebViewOptions(
          useShouldOverrideUrlLoading: true,
          useOnDownloadStart: true,
        ),
        android: AndroidInAppWebViewOptions(useHybridComposition: true),
        ios: IOSInAppWebViewOptions(allowsInlineMediaPlayback: true),
      ),
      onWebViewCreated: (controller) {
        webviewController = controller;
        widget.arguments[GKeys.webviewController] = webviewController;
      },
      shouldOverrideUrlLoading: (controller, navigationAction) async {
        var uri = navigationAction.request.url!;
        if (!GUtils.whiteListedSchemesForWV.contains(uri.scheme)) {
          if (await canLaunchUrl(uri)) {
            await launchUrl(uri);
            return NavigationActionPolicy.CANCEL;
          }
        }
        if (navigationAction.isForMainFrame) {
          /*Progress dialog push handling being done here, so that user doesn't feel
          that screen is unresponsive for long, after link click*/
          showProgDialogHandler();
        }
        return NavigationActionPolicy.ALLOW;
      },
      onTitleChanged: (controller, title) {
        if (title != null && title.isNotEmpty) {
          setState(() => pageTitle = title);
        }
      },
      onLoadStart: (_, __) {
        showProgDialogHandler();
      },
      onLoadStop: (controller, __) {
        hideProgDialogHandler();
      },
      onReceivedError: (_, __, ___) {
        hideProgDialogHandler();
      },
      onDownloadStartRequest: (_, downloadStartReq) {
        /*Progress dialog pop handling being done here, because for a download URL in iOS,
        [onLoadError] gets called after [onDownloadStartRequest]
        and [onLoadStop] never gets called, which hangs the app*/
        hideProgDialogHandler();
      },
    );
  }

  showProgDialogHandler() {
    if (!progDialogShowing) {
      GUtils.showProgressDialog();
      progDialogShowing = true;
    }
  }

  hideProgDialogHandler() {
    Future.delayed(
      const Duration(milliseconds: 200),
      () {
        if (progDialogShowing) {
          Navigator.pop(context);
          progDialogShowing = false;
        }
      },
    );
  }
}

==> global-0.0.32.tar.gz: lib/src/routes/GWebViewRoute.dart <==
import 'package:flutter/material.dart';
import 'package:global/global.dart';

abstract class GWebViewRoute extends StatefulWidget {
  final Map<String, dynamic> arguments;

  const GWebViewRoute(this.arguments, {super.key});
}

abstract class GWebViewRouteState<T extends GWebViewRoute>
    extends State<GWebViewRoute> {
  late String pageTitle;
  late InAppWebViewController webviewController;
  late InAppWebView webView;
  Uri? initialUri;

  @override
  void initState() {
    super.initState();
    initialUri = Uri.tryParse(widget.arguments[GKeys.initialWebviewData]);
    pageTitle = GTexts.untitled;
    webView = InAppWebView(
      initialData: initialUri == null
          ? InAppWebViewInitialData(
              data: widget.arguments[GKeys.initialWebviewData])
          : null,
      initialUrlRequest:
          initialUri == null ? null : URLRequest(url: WebUri.uri(initialUri!)),
      initialSettings: InAppWebViewSettings(
        useShouldOverrideUrlLoading: true,
        useOnDownloadStart: true,
        useHybridComposition: true,
        allowsInlineMediaPlayback: true,
      ),
      onWebViewCreated: (controller) {
        webviewController = controller;
        widget.arguments[GKeys.webviewController] = webviewController;
      },
      shouldOverrideUrlLoading: (controller, navigationAction) async {
        var uri = navigationAction.request.url!;
        if (!GUtils.whiteListedSchemesForWV.contains(uri.scheme)) {
          if (await canLaunchUrl(uri)) {
            await launchUrl(uri);
            return NavigationActionPolicy.CANCEL;
          }
        }
        return NavigationActionPolicy.ALLOW;
      },
      onTitleChanged: (controller, title) {
        if (title != null && title.isNotEmpty) {
          setState(() => pageTitle = title);
        }
      },
      onDownloadStartRequest: (_, downloadStartReq) =>
          GUtils.onFileDownloadStartRequest(url: downloadStartReq.url.rawValue),
    );
  }
}
